#!/bin/sh
#
# QLogic Fibre Channel Event reader
# Copyright (C) 2008 QLogic Corporation
# (www.qlogic.com)
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
version=1.00
dfs=debugfs
def_mnt=/sys/kernel/debug
fce_path=qla2xxx/qla2xxx_${1}/fce
fce_dfile=fce_dump_${1}_`eval date +%Y%m%d_%H%M%S`.txt

die() {
	echo >&2 "$@"
	exit 1
}

# Get host number
if [ -z "${1}" ] ; then
	echo "QLogic FCE Reader: ${version}"
	echo "Usage:"
	echo "   `basename ${0}` <host_no>"
	exit 1
fi

# Remount debugfs if necessary
mount_point=$(mount | grep ${dfs} | cut -d' ' -f3)
if [ -z "${mount_point}" ] ; then
	mount -t ${dfs} none ${def_mnt} 2>/dev/null ||
		die "Unable to mount ${dfs} for FCE extraction."
	mount_point=${def_mnt}
fi

# Verify fw_dump binary-attribute file
fce=${mount_point}/${fce_path}
test -f ${fce} ||
	die "No FCE file at host ${1}!!!"
cat ${fce} > ${fce_dfile} ||
	die "Unable to extract FCE file at host ${1}!!!"
gzip ${fce_dfile}
echo "FCE dumped to file ${fce_dfile}.gz."

exit 0
